package com.osi.notification;

import java.io.Serializable;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.DeliveryMode;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.ObjectMessage;
import javax.jms.Session;
import javax.naming.Context;
import javax.naming.InitialContext;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class NotificationHelper {
	
	private static final Logger log = LoggerFactory.getLogger(NotificationHelper.class);
	private static ConnectionFactory factory;
	private static Context ctx;

	static {
		try {
			ctx = new InitialContext();
			factory = (ConnectionFactory)ctx.lookup("java:/JmsXA");
		} catch (Exception e) {
			log.error("Failed to get necessary resources.", e);
		}
	}

	public static void sendNotification(Object notification, Destination destination) throws JMSException {
		log.debug("Sending Notification");
		log.trace("NOTIFICATION: {}", notification);
        Connection connection = null;
        Session session = null;
        MessageProducer producer = null;
        try {
            connection = factory.createConnection();
            session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
            log.trace("THE DESTINATION: {}", destination);
            producer = session.createProducer(destination);
            producer.setDeliveryMode(DeliveryMode.NON_PERSISTENT);
            
            ObjectMessage message = session.createObjectMessage();
            message.setObject((Serializable)notification);
            message.setStringProperty("myproperty", "myvalue");
            log.trace("SENDING JMS MESSAGE: {} WITH PROPERTIES: {}", message, message.getPropertyNames());
            
            producer.send(message);
        }
        finally {
			if (connection != null) {
				try { connection.close(); }
				catch (Exception e) {
        			log.error("Error Closing Connection", e);
				}
			}
        }
	}

	
}
