package com.osi.notification.subscription;

import org.apache.commons.httpclient.Header;
import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.HttpStatus;
import org.apache.commons.httpclient.methods.DeleteMethod;
import org.apache.commons.httpclient.methods.PostMethod;
import org.apache.commons.httpclient.methods.StringRequestEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class SubscriptionHelper {
	
	private static final Logger log = LoggerFactory
			.getLogger(SubscriptionHelper.class);

	public static RESTSubscriptionResponse createQueueRESTPushSubscription(String queueName, String pushEndpoint, String baseUri) throws Exception {
		
		log.trace("BASE URI: {}", baseUri);
		
		HttpClient client = new HttpClient();
		PostMethod request = new PostMethod(baseUri + "hornetq-rest/queues/jms.queue." + queueName + "/push-consumers");
		String subString = "<push-registration><link href='" + pushEndpoint + "' type='application/json' method='PUT' /><disableOnFailure>false</disableOnFailure></push-registration>";
		request.setRequestEntity(new StringRequestEntity(subString, "application/xml", null));
		final int status = client.executeMethod(request);
		if (status == HttpStatus.SC_CREATED) {
			if (log.isTraceEnabled()) {
				for (Header header : request.getResponseHeaders()) {
					log.trace("SUBSCRIBE RESPONSE HEADER: NAME[{}] VALUE[{}]", header.getName(), header.getValue());
				}
				String body = request.getResponseBodyAsString();
				if (body != null && !body.isEmpty()) {
					log.trace("RESPONSE BODY: {}", body);
				}
			}
			
			return new RESTSubscriptionResponse(HttpStatus.SC_CREATED, 
					request.getResponseHeader("Location").getValue());
		} else {
			return new RESTSubscriptionResponse(status);
		}
	}
	
	public static void unsubscribe(String unsubscribeUri) throws Exception {
		log.debug("Removing subscription: {}", unsubscribeUri);
		HttpClient client = new HttpClient();
		client.executeMethod(new DeleteMethod(unsubscribeUri));
	}
}
